;****************************************************************************
;
;                              E V 1 3 . 1 7 2
;
;                       C U S T O M E R   E Q U A T E S
;
;                             1 2   A p r   9 6
;
;  When making changes to the formula entries below, only change the integer
;  value.  Do not remove or change the curly braces {} contained in any of
;  the formulas.  They are required for the assembler.
;
;****************************************************************************
;  These constants are the scaling factors used to formulate set and trip
;  points, multiplied by either VOLTS_MULTIPLY or AMPS_MULTIPLY.  To determine
;  the proper settings, first assemble the program and then start the charging
;  process.  Next, determine the voltage and current readings from the
;  diagnostic program.  Then take actual measurements for both voltage and
;  current.  The following formula may then be used to determine the new
;  calibration settings:
;
;                       Diagnostic Displayed Reading
; New Calib Setting =   -----------------------------  * Present Scaling Factor
;                          Actual Measured Reading
;
;     Default Setting for Voltage = 4867  ;   .4867 * 10000
;     Default Setting for Current = 1050  ; 10.50   * 100
;
VOLTS_SCALE:    equ     4867              ;   .4867 * 10000
;
AMPS_SCALE:     equ     1050              ; 10.50   * 100

;****************************************************************************
;
;                    B A T T E R Y   I N F O R M A T I O N
;
;  Battery.  This defines the total number of batteries in series for this
;  vehicle.  Packs defines the number of parallel strings within the battery
;  pack.  Cells defines the number of cells per battery.
;
;     Battery Type Conversion Table
;
;        Type Battery 0  = Type Of Battery Unknown or Not Listed Below
;        Type Battery 1  = Gates (SLA) G12V38AH
;        Type Battery 2  = Gates (SLA) G12V26AH
;        Type Battery 3  = GNB (SLA) Upsolyte
;        Type Battery 4  = GNB (SLA) Evolyte
;        Type Battery 5  = GNB (SLA) Champion
;        Type Battery 6  = Sonnenshein (SLA)
;        Type Battery 7  = Trojan TEB225
;        Type Battery 8  = Genesis (SLA) G12V38AH10C
;        Type Battery 9  = Electrosource 12N95
;        Type Battery 10 = Ovonic OVC12 Nickel Metal Hydride
;
;     Valid Range = 1 - 255
;
TYPE_BATTERY:   equ     0                 ;Battery Type Unknown
BATTERIES:      equ     27                ;Number of batteries in series
STRINGS:        equ     4                 ;Number of strings in pack
CELLS:          equ     6                 ;Number of cells per battery
AMP_HOURS:      equ     85                ;Amphour capacity of Battery Pack

;  Battery pack maximum voltage allowed for this vehicle.  Any voltage above
;  this value will terminate the charging process.
;
;     Valid Range    =  0 - 500 VDC
;     Normal Value   =  (2.8 vpc) (Number of Cells) ( Number of Batteries)
;     Default Value  =  400
;
VMAX:           equ     {400*VOLTS_SCALE}/VOLTS_MULTIPLY

;  Battery pack minimum voltage allowed for this vehicle.  Any voltage below
;  this point will inhibit charging.
;
;     Valid Range    =  0 - 500 VDC
;     Normal Value   =  (1.66 vpc) (Number of Cells) ( Number of Batteries)
;
VMIN:           equ     {350*VOLTS_SCALE}/VOLTS_MULTIPLY

;****************************************************************************
;  Power Up Delay.  This is the amount of time delay after connection present
;  is detected until the charging process begins.
;
;     Valid Range   = 0 - 59 seconds
;     Default Value = 10 seconds
;
PUD:            equ     10                ;Power up delay

;  Time Maximum.  This is the maximum amount of charging time allowed, in
;  hours, for all modes combined.  If the system clock exceeds this time limit,
;  the charge controller will enter Mode 6.
;
;     Valid Range   = 0 - 255 Hours
;     Default Value = 24 hours
;
TMAX:           equ     24                ;Total Maximum system charging time
;****************************************************************************


;****************************************************************************
;
;                    M O D E   1   P A R A M E T E R S
;
;  Mode 1 Voltage Set Point.  This is the charging voltage that should be
;  maintained while in Mode 1.
;
;     Valid Range = 0 - 500 VDC
;
V1:             equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY
 
;  Mode 1 Current Trip Point.  This is the amperage that will cause the charge
;  controller to trip from Mode 1 into Mode 2.  Entries must be integer
;  numbers.  Multiply the required entry by a factor of 10 before entering.
;  For instance, if the desired amperage is 15, an entry of 150 (15 * 10) is
;  required.  To set 12.7 amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
ITRIP1:         equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}
 
;  Mode 1 Maximum Current (IMax_Mode1).  This is the maximum amount of current
;  which may be applied during Mode 1.  Prevents current from running wild.
;
;  NOTE:  Must have a value to charge in this mode!
;
;     Valid Range    = 0 - 200 where 200 = 20.0 Amps
;
IMAX_MODE1:     equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  The Bypass_TripPt1 flag indicates the trip point for Mode 1 will be ignored.
;  This will then cause Mode 1 to operate until the time settings in T1_HOURS
;  and T1_MIN has elapsed.
;
;     Valid Range    =  0 = Don't bypass Mode 1 trip point.
;                    =  1 = Do bypass Mode 1 trip point.
;     Default Value  =  0 = Don't bypass Mode 1 trip point.
;
BYPASS_TRIPPT1: equ     0                 ;Don't bypass Mode 1 Trip Point

;  Mode 1 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 1.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T1_HOURS:       equ     0                 ;Mode 1 timeout in hours
T1_MIN:         equ     0                 ;Mode 1 timeout in minutes
;****************************************************************************


;****************************************************************************
;
;                    M O D E   2   P A R A M E T E R S
;
;  Mode 2 Voltage Set Point.  This is the charging voltage that should be
;  maintained while in Mode 2.
;
;     Valid Range = 0 - 500 VDC
;
V2:             equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY
 
;  Mode 2 Voltage reStart Level.  This constant signifies the voltage level
;  that is used to determine when to restart the charging process.  Upon Charge
;  Complete, once an hour the battery pack voltage is monitored.  Should the
;  raw voltage fall below the V_START_LEVEL, and the DO_TOP_OFFS flag is set,
;  Mode 2 is entered and charging will occur until Mode 2 exit parameters are
;  met.  This setting MUST have a value if the DO_TOP_OFFS flag is enabled!
;
;     Valid Range    = 0 - 500 VDC
;     Normal Value   = 
;
V_START_LEVEL:  equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY

;  Mode 2 Current Trip Point.  This is the amperage that will cause the charge
;  controller to trip from Mode 2 into Completion Mode.  Entries must be
;  integer numbers.  Multiply the required entry by a factor of 10 before
;  entering.  For instance, if the desired amperage is 15, an entry of 150
;  (15 * 10) is required.  To set 12.7 amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
ITRIP2:         equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}
 
;  Mode 2 Maximum Current (IMax_Mode2).  This is the maximum amount of current
;  which may be applied during Mode 2.  Prevents current from running wild.
;
;  NOTE:  Must have a value to charge in this mode!
;
;     Valid Range    = 0 - 200 where 200 = 20.0 Amps
;
IMAX_MODE2:     equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  The Bypass_TripPt2 flag indicates the trip point for Mode 2 will be ignored.
;  This will then cause Mode 2 to operate until the time settings in T2_HOURS
;  and T2_MIN has elapsed.
;
;     Valid Range    =  0 = Don't bypass Mode 2 trip point.
;                    =  1 = Do bypass Mode 2 trip point.
;     Default Value  =  0 = Don't bypass Mode 2 trip point.
;
BYPASS_TRIPPT2: equ     0                 ;Don't bypass Mode 2 Trip Point

;  Mode 2 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 2.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T2_HOURS:       equ     0                 ;Mode 2 timeout in hours
T2_MIN:         equ     0                 ;Mode 2 timeout in minutes
;****************************************************************************

 
;****************************************************************************
;
;                    M O D E   3   P A R A M E T E R S
;
;  Mode 3 Voltage Set Point.  This is the charging voltage that should be
;  maintained while in Mode 3.  Traction Pack topping off..
;
;     Valid Range = 0 - 500 VDC
;
V3:             equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY
 
;  Mode 3 Current Trip Point.  This is the amperage that will cause the charge
;  controller to trip from Mode 3 into Completion Mode.  Entries must be integer
;  numbers.  Multiply the required entry by a factor of 10 before entering.
;  For instance, if the desired amperage is 15, an entry of 150 (15 * 10) is
;  required.  To set 12.7 amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
ITRIP3:         equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}
 
;  Mode 3 Maximum Current (IMax_Mode3).  This is the maximum amount of current
;  which may be applied during Mode 3.  Prevents current from running wild.
;
;  NOTE:  Must have a value to charge in this mode!
;
;     Valid Range    = 0 - 200 where 200 = 20.0 Amps
;
IMAX_MODE3:     equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  The Bypass_TripPt3 flag indicates the trip point for Mode 3 will be ignored.
;  This will then cause Mode 3 to operate until the time settings in T3_HOURS
;  and T3_MIN has elapsed.
;
;     Valid Range    =  0 = Don't bypass Mode 3 trip point.
;                    =  1 = Do bypass Mode 3 trip point.
;     Default Value  =  0 = Don't bypass Mode 3 trip point.
;
BYPASS_TRIPPT3: equ     0                 ;Don't bypass Mode 3 Trip Point

;  Mode 3 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 3.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T3_HOURS:       equ     0                 ;Mode 3 timeout in hours
T3_MIN:         equ     0                 ;Mode 3 timeout in minutes
;****************************************************************************

 
;****************************************************************************
;
;                    M O D E   4   P A R A M E T E R S
;
;  Mode 4 Voltage Set Point.  This is the charging voltage that should be
;  maintained while in Mode 4.  Auxiliary battery topping off.
;
;     Valid Range = 0 - 500 VDC
;
V4:             equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY

;  Mode 4 Current Trip Point.  This is the amperage that will cause the charge
;  controller to trip from Mode 4 into Completion Mode.  Entries must be
;  integer numbers.  Multiply the required entry by a factor of 10 before
;  entering.  For instance, if the desired amperage is 15, an entry of 150 (15
;  * 10) is required.  To set 12.7 amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
ITRIP4:         equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  Mode 4 Maximum Current (IMax_Mode4).  This is the maximum amount of current
;  which may be applied during Mode 4.  Prevents current from running wild.
;
;  NOTE:  Must have a value to charge in this mode!
;
;     Valid Range    = 0 - 200 where 200 = 20.0 Amps
;
IMAX_MODE4:     equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  The Bypass_TripPt4 flag indicates the trip point for Mode 4 will be ignored.
;  This will then cause Mode 4 to operate until the time settings in T4_HOURS
;  and T4_MIN has elapsed.
;
;     Valid Range    =  0 = Don't bypass Mode 4 trip point.
;                    =  1 = Do bypass Mode 4 trip point.
;     Default Value  =  0 = Don't bypass Mode 4 trip point.
;
BYPASS_TRIPPT4: equ     0                 ;Don't bypass Mode 4 Trip Point

;  Mode 4 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 4.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T4_HOURS:       equ     0                 ;Mode 4 timeout in hours
T4_MIN:         equ     0                 ;Mode 4 timeout in minutes
;****************************************************************************


;******************************************************************************
;  Temperature Sensor Monitoring
;
;  Temperature sensors are normally installed in the battery pack area to
;  assist in thermal management of the batteries.  If this constant is set to a
;  one (1), the temperature sensors will be enabled.  If set to a zero (0), no
;  monitoring of the temperature sensors will occur.  Set this flag to 1 only
;  if the additional hardware for temperature sensors has been installed in the
;  vehicle.
;
;     Valid Range    =  0 = Don't perform Temperature Sensor monitoring.
;                    =  1 = Do perform Temperature Sensor monitoring.
;     Default Value  =  0 = Don't perform Temperature Sensor monitoring.
;
MON_TEMP_SENSE: equ     0                 ;Don't Monitor Temperature Sensors

;******************************************************************************
;  TempMax defines the maximum temperature (in Kelvin) allowed to be detected
;  by the temperature sensors.  If this value is exceeded, Fault Mode is
;  entered.
;
;     Valid Range    = 243 - 348 degrees Kelvin
;     Normal Value   = 348 degrees Kelvin
;     Default Value  = 348 degrees Kelvin
;
TEMPMAX:        equ     {{{{348*LSB_PER_KELVIN}-{243*LSB_PER_KELVIN}}+50}/100}
                                          ;range = -30 C  to +75 C
                                          ;      = 243 K  to 348 K
                                          ;348 = 348 degrees kelvin
                                          ;348 K * 2.11 lsb/K - 523.77 = 210
                                          ;LSB_PER_KELVIN defined in equates.h
                                          ;243 = Min Kelvin temp read by sensor
                                          ;50 = .5 * 100 for rounding integer
                                          ;100 = offset used on LSB_PER_KELVIN
                                          ; to make it an integer.


;****************************************************************************
;  TempMin defines the minimum temperature (in Kelvin) allowed to be detected
;  by the temperature sensors.  If temperature drops below this value, Fault
;  Mode is entered.
;
;     Valid Range    = 243 - 348 degrees Kelvin
;     Normal Value   = 253 degrees Kelvin
;     Default Value  = 253 degrees Kelvin
;
TEMPMIN:        equ     {{{{253*LSB_PER_KELVIN}-{243*LSB_PER_KELVIN}}-50}/100}
                                          ;range = -30 C  to +75 C
                                          ;      = 243 K  to 348 K
                                          ;253 = 253 degrees kelvin
                                          ;253 K * 2.11 lsb/K - 512.73 = 20
                                          ;LSB_PER_KELVIN defined in equates.h
                                          ;243 = Min Kelvin temp read by sensor
                                          ;50 = .5 * 100 for rounding integer
                                          ;100 = offset used on LSB_PER_KELVIN
                                          ; to make it an integer.

;****************************************************************************
;
;              T E M P E R A T U R E   C O M P E N S A T I O N
;
;  Temperature Compensation Flag.  This constant should be set to a 1 (one) if
;  temperature compensation is desired.  If not desired, set this constant to
;  0 (zero).  Compensation can only work if temperature sensors are installed.
;
;     Valid Range    =  0 = Don't perform temperature compensation
;                       1 = Do perform temperature compensation
;     Default Value  =  0 = Don't perform temperature compensation
;
TEMP_COMP_FLAG: equ     0                 ;0 = No Temperature Compensation

;  Temperature Compensation Maximum and Minimum Voltages.  These constants
;  define voltage limits for the temperature compensation routines.  Voltage
;  should not exceed Temp_Max_Volts nor drop below Temp_Min_Volts.  Note: The
;  values set below are ignored if temperature compensation is not enabled.
;  TEMP_MAX_VOLTS should not be set above VMAX.
;
;     Valid Range = 0 - 500 VDC
;     Normal Max Value = (2.5 vpc) (Number of Cells) ( Number of Batteries)
;     Normal Min Value = (2.2 vpc) (Number of Cells) ( Number of Batteries)
;
TEMP_MAX_VOLTS: equ     {400*VOLTS_SCALE}/VOLTS_MULTIPLY
TEMP_MIN_VOLTS: equ     {352*VOLTS_SCALE}/VOLTS_MULTIPLY

;  Temperature Compensation required per cell, per degree celsius.  This
;  constant is then used when determining the required offset voltage.  When
;  entering values, the value must be integer, and not preceeded by a zero.
;  The value represents millivolts per cell, per degree celsius.
;
;     Valid Range   = 0 - 999 where 999 equals 9.99mv per cell per degree C.
;     Default Value = 444                 ;Lead Acid Battery
;
TEMP_COMP_MV:   equ     444               ;4.44mv per cell

;  Temperature which is considered Nominal for the batteries used in this EV
;  application.  Temperature compensation will be calculated based on this
;  nomimal temperature.
;
;     Default Value = 25 degrees C        ;Lead Acid Battery
;
TEMP_NOMINAL_C: equ     25                ;Degrees Celsius

;****************************************************************************
;  Gain factors for the control loop.
;
I_COR:          equ     1                 ; scaled constant current gain (Kcc)
                                          ; range = 0 - 128
 
V_COR:          equ     4                 ; scaled constant voltage gain (Kcv)
                                          ; range = 0 - 248

;****************************************************************************
;
;  Special Flags and Variables for specific installations
;
;  Amp Hour Maximum Limit represents the maximum cumulative amphours allowed to
;  be returned to the battery pack during this charging cycle.  If this limit
;  is exceeded during the charging cycle, Fault Mode is entered.
;
;     Valid Range    =  10% - 200% of Battery Pack AmpHour Capacity
;     Normal Value   =  130% of Battery Pack AmpHour Capacity.
;
AMPHR_MAXLIMIT: equ     {{130*AMP_HOURS}+50}/100   ;Cumulative Maximum AmpHours
                                                   ; which may be applied

;  Dolphin Monitoring
;
;  The Dolphin unit, if installed, may be monitored via additional hardware for
;  various fault conditions.  If the Lid is opened, the vehicle key turned on,
;  the Dolphin contactor fail, or the FET turn off, the Dolphin precharge
;  circuit may be damaged if charging continues.  If any of the mentioned
;  failures are detected, charging will be terminated with a fault mode.  The
;  use of the additional hardware and software monitoring prevents this damage
;  from occurring.  Set this flag to 1 only if the additional hardware has been
;  installed in the vehicle and charge controller to monitor the Dolphin unit.
;
;     Valid Range    =  0 = Don't perform additional Dolphin monitoring.
;                    =  1 = Do perform additional Dolphin monitoring.
;     Default Value  =  1 = Do perform additional Dolphin monitoring.
;
MON_DOLPHIN:    equ     1                 ;Monitor Dolphin Unit Status

;  Auxiliary Battery Monitoring
;
;  The Auxiliary Battery voltage may be monitored via additional hardware for
;  state of charge.  The auxiliary battery may be damaged if over charged or
;  the state of charge falls to low.  If the auxiliary battery voltage exceeds
;  14.3vdc or falls below 11.0vdc, charging will be terminated with a fault
;  mode.  Set this flag to 1 only if the additional hardware has been installed
;  in the vehicle and charge controller to monitor the Auxiliary Battery.
;
;     Valid Range    =  0 = Don't perform Auxiliary Battery monitoring.
;                    =  1 = Do perform Auxiliary Battery monitoring.
;     Default Value  =  1 = Do perform Auxiliary Battery monitoring.
;
MON_AUX_BATT:   equ     1                 ;Monitor Dolphin Unit Status


;  The DO_TOP_OFFS flag indicates the desire to perform traction pack and aux
;  battery pack topping off once Completion Mode has been entered.  If the flag
;  is set, traction pack topping off will be monitored once every hour and aux
;  battery voltage will be continuously monitored. Should traction pack voltage
;  be at or below the level specified in V_START_LEVEL (see MODE 2 parameters),
;  Mode 2 will be re-entered and topping off will occur.  If the aux battery
;  voltage falls to or below 12.4 volts, Mode 4 will be entered.  If the flag
;  is set to a zero, no topping off will occur.
;
;     Valid Range    =  0 = Don't perform traction pack or aux battery top off.
;                    =  1 = Do perform traction pack and aux battery top off.
;     Default Value  =  1 = Do perform traction pack and aux battery top off.
;
DO_TOP_OFFS:    equ     1                 ;Do perform traction pack and aux
                                          ;battery topping off.

;  The LEVEL_AFTER constant represents how many charge complete cycles must
;  be processed before a mandatory traction pack leveling (Mode 3) will occur.
;  Once this value has been met, the EEPROM counter will be reset to 0 and the
;  next power-on cycle will cause mandatory entry into Mode 3 for a traction
;  pack leveling cycle.
;
;     Valid Range    =  0 - 255
;     Default Value  =  5
;
LEVEL_AFTER:    equ     5                 ;Mandatory traction pack leveling
                                          ;after LEVEL_AFTER charge complete
                                          ;cycles.
;****************************************************************************
;
;                      E N D   O F   C U S T O M E R . H
;
;****************************************************************************
